%define _disable_ld_no_undefined 1

# extracted from sip.h, SIP_API_MAJOR_NR SIP_API_MINOR_NR defines
%define sip_api_major 12
%define sip_api_minor 2
%define sip_api       %{sip_api_major}.%{sip_api_minor}

# Force python3 build - required by new hplip
# % {?build_python3}%{?!build_python3:%bcond_without python3}
%bcond_without python3

Summary:	Riverbanks's python sip
Name:		python-sip
Version:	4.19.3
Release:	1
Epoch:		3
License:	GPLv2+
Group:		Development/Python
Url:		http://www.riverbankcomputing.co.uk/software/sip/intro
Source0:	http://downloads.sourceforge.net/pyqt/sip-%{version}.tar.gz
Patch0:		sip-4.18.1-python3-bin.patch
BuildRequires:	bzip2-devel
BuildRequires:	pkgconfig(python)
%if %{with python3}
BuildRequires:	pkgconfig(python3)
%endif
Requires:	sip-macros = %{EVRD}
Provides:	sip-api(%{sip_api_major}) = %{sip_api}

%description
SIP is a tool that makes it very easy to create Python bindings
for C and C++ libraries. It was originally developed to create PyQt,
the Python bindings for the Qt toolkit, but can be used to
create bindings for any C or C++ library.

%files
%{_bindir}/sip
%{py_incdir}/sip.h
%{py_platsitedir}/sip*

#----------------------------------------------------------------------------
%if %{with python3}

%package -n python3-sip
Summary:	Riverbanks's python sip
Group:		Development/Python
Requires:	sip-macros = %{EVRD}
Conflicts:	python3-sip < 3:4.16.1-3
Obsoletes:	python3-sip < 3:4.16.1-3
Conflicts:	python3-sip-devel < 3:4.16.1-3
Obsoletes:	python3-sip-devel < 3:4.16.1-3
Provides:	python3-sip-api(%{sip_api_major}) = %{sip_api}

%description -n python3-sip
SIP is a tool that makes it very easy to create Python bindings
for C and C++ libraries. It was originally developed to create PyQt,
the Python bindings for the Qt toolkit, but can be used to
create bindings for any C or C++ library.

%files -n python3-sip
%{_bindir}/sip3
%{py3_incdir}/sip.h
%{py3_platsitedir}/sip*

%endif
#----------------------------------------------------------------------------

%package -n sip-macros
Summary:	RPM macros for python sip
Group:		Development/Python
Conflicts:	python-sip < 3:4.16.1-3
Conflicts:	python3-sip-devel < 3:4.16.1-3

%description -n sip-macros
RPM macros for python sip.

%files -n sip-macros
%{_sysconfdir}/rpm/macros.d/sip.macros

#----------------------------------------------------------------------------

%prep
%setup -qcn sip-%{version}

pushd sip-%{version}
# Check API minor/major numbers
export real_api_major=`grep SIP_API_MAJOR_NR siplib/sip.h.in|head -n1|awk -F' ' '{print $3}'`
export real_api_minor=`grep SIP_API_MINOR_NR siplib/sip.h.in|head -n1|awk -F' ' '{print $3}'`
if [ $real_api_major -ne %{sip_api_major} ]; then
    echo 'Wrong spi major specified: Should be' $real_api_major ', but set' %{sip_api_major}
    exit 1
fi
if [ $real_api_minor -ne %{sip_api_minor} ]; then
    echo 'Wrong spi minor specified: Should be' $real_api_minor ', but set' %{sip_api_minor}
    exit 1
fi

#  Don't use X11R6 prefix for includes neither libraries by default.
for file in specs/linux-*; do
    perl -p -i -e "s@/X11R6/@/@g" $file
done
popd

mv sip-%{version} python2

%if %{with python3}
cp -r python2 python3

pushd python3
%patch0 -p1
popd
%endif

%build
pushd python2
python2 configure.py
%make CFLAGS="%{optflags} -fPIC" CXXFLAGS="%{optflags} -fPIC" LIBS="%{?ldflags} -lpython%{py_ver}"
popd

%if %{with python3}
pushd python3
python3 configure.py --sipdir=%{_datadir}/sip3
%make CFLAGS="%{optflags} -fPIC" CXXFLAGS="%{optflags} -fPIC" LIBS="%{?ldflags} -lpython%{py3_ver}"
popd
%endif

%install
%makeinstall_std -C python2
%if %{with python3}
%makeinstall_std -C python3
%endif

mkdir -p %{buildroot}%{_sysconfdir}/rpm/macros.d/
cat > %{buildroot}%{_sysconfdir}/rpm/macros.d/sip.macros << EOF
# extracted from sip.h, SIP_API_MAJOR_NR SIP_API_MINOR_NR defines
%%sip_api_major %{sip_api_major}
%%sip_api_minor %{sip_api_minor}
%%sip_api       %{sip_api_major}.%{sip_api_minor}
EOF

%changelog

* Thu Sep 07 2017 Andrey Bondrov <andrey.bondrov@rosalab.ru> 3:4.19.3-1
- (1aba5d7) New version 4.19.3
- (1aba5d7) New sip API 12.2

* Sat Feb 25 2017 Andrey Bondrov <andrey.bondrov@rosalab.ru> 3:4.19.1-1
- (687047f) New version 4.19.1
- (687047f) New SIP API 12.1

* Sat Feb 04 2017 Andrey Bondrov <andrey.bondrov@rosalab.ru> 3:4.18.1-3
- (de49667) MassBuild#1230: Increase release tag

* Fri Oct 14 2016 Andrey Bondrov <andrey.bondrov@rosalab.ru> 3:4.18.1-2
- (bd5c918) MassBuild#1169: Increase release tag

* Thu Sep 22 2016 Denis Silakov <dsilakov@gmail.com> 3:4.18.1-1
- (c5f2e94) Updated to 4.18.1

* Fri Aug 26 2016 Denis Silakov <denis.silakov@rosalab.ru> 3:4.16.7-6
- (82c4c4c) Rebuild

* Thu Apr 07 2016 Denis Silakov <dsilakov@gmail.com> 3:4.16.7-5
- (dcf0764) Updated to 4.16.7 - latest version with the same API

* Thu Feb 04 2016 Denis Silakov <dsilakov@gmail.com> 3:4.16.5-5
- (af573df) Rebuild with python 3.5

* Wed Jun 17 2015 Denis Silakov <denis.silakov@rosalab.ru> 3:4.16.5-4
- (3f9fa23) Force python3 build - required by new hplip

* Sun Feb 22 2015 Alexander Lakhin <a.lahin@ntcit-rosa.ru> 3:4.16.5-3
- (fd5355e) MassBuild#656: Increase release tag

* Tue Jan 27 2015 Denis Silakov <denis.silakov@rosalab.ru> 3:4.16.5-2
- (6f2f965) Fix python3 conditional build

* Mon Dec 29 2014 Denis Silakov <denis.silakov@rosalab.ru> 3:4.16.5-1
- (12b6c60) Updated to 4.16.5

* Fri Oct 24 2014 Andrey Bondrov <andrey.bondrov@rosalab.ru> 3:4.16.1-3
- (a31a8aa) Build python3-sip

* Wed Jul 02 2014 Andrey Bondrov <andrey.bondrov@rosalab.ru> 3:4.16.1-1
- (8aef040) New version 4.16.1

* Fri Jun 27 2014 Alex Burmashev <alex.burmashev@rosalab.ru> 3:4.15.5-4
- (ab6f372) MassBuild#440: Increase release tag

* Mon Jun 23 2014 Denis Silakov <denis.silakov@rosalab.ru> 3:4.15.5-3
- (82ec38c) Fix macro names
- (Denis Silakov: fc299f4) Added rpm macros

* Fri Apr 11 2014 Andrey Bondrov <andrey.bondrov@rosalab.ru> 3:4.15.5-2
- (475149c) New version 4.15.5 (finally we can switch)

* Wed Mar 26 2014 Denis Silakov <denis.silakov@rosalab.ru> 3:4.14.5-2
- (c3c25cd) Revert to 4.14.5

* Mon Mar 17 2014 Denis Silakov <denis.silakov@rosalab.ru> 2:4.15.5-1
- (d8462d1) Updated to 4.15.5 (by updates_builder)

* Tue Nov 19 2013 Denis Silakov <denis.silakov@rosalab.ru> 2:4.15.3-1
- (da8f6b6) LOG Updated to 4.15.3 (by updates_builder)

* Thu Nov 14 2013 Denis Silakov <denis.silakov@rosalab.ru> 2:4.14.5-1
- (a847b8c) Turn back 4.14.5 for now

* Mon Nov 11 2013 Denis Silakov <denis.silakov@rosalab.ru> 1:4.15.3-1
- (caa737a) LOG Updated to 4.15.3 (by updates_builder)

* Wed Oct 16 2013 Denis Silakov <denis.silakov@rosalab.ru> 1:4.15.2-1
- (ca34faa) LOG Updated to 4.15.2 (by updates_builder)

* Thu Apr 18 2013 Andrey Bondrov <andrey.bondrov@rosalab.ru> 1:4.14.5-1
- (5b63a0b) LOG New version 4.14.5

* Mon Oct 22 2012 Denis Silakov <denis.silakov@rosalab.ru> 1:4.13.3-1
- (dd41c61) Added tarball itself
- (Denis Silakov: e885d8a) Fix .abf.yaml
- (Denis Silakov: 23a1123) Added .abf.yaml
- (Andrey Bondrov: 04755aa) Update to 4.13.3

* Wed Jun 20 2012 Andrey Bondrov <andrey.bondrov@rosalab.ru> 1:4.13.2-1
- (c422cb6) Update to 4.13.2


